# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui/mainform.ui'
#
# Created: Thu Sep  8 16:31:03 2011
#      by: PyQt4 UI code generator 4.7.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(689, 559)
        MainWindow.setMinimumSize(QtCore.QSize(100, 100))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/main.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setDocumentMode(False)
        MainWindow.setDockNestingEnabled(False)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_2 = QtGui.QGridLayout(self.centralwidget)
        self.gridLayout_2.setSpacing(1)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 1)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.tabWidget = QtGui.QTabWidget(self.centralwidget)
        self.tabWidget.setMinimumSize(QtCore.QSize(100, 100))
        self.tabWidget.setUsesScrollButtons(True)
        self.tabWidget.setDocumentMode(True)
        self.tabWidget.setTabsClosable(False)
        self.tabWidget.setMovable(False)
        self.tabWidget.setObjectName("tabWidget")
        self.text_tab = QtGui.QWidget()
        self.text_tab.setObjectName("text_tab")
        self.gridLayout_3 = QtGui.QGridLayout(self.text_tab)
        self.gridLayout_3.setMargin(0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.tabWidget.addTab(self.text_tab, "")
        self.html_tab = QtGui.QWidget()
        self.html_tab.setObjectName("html_tab")
        self.gridLayout_5 = QtGui.QGridLayout(self.html_tab)
        self.gridLayout_5.setMargin(0)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.webView = QtWebKit.QWebView(self.html_tab)
        self.webView.setUrl(QtCore.QUrl("about:blank"))
        self.webView.setObjectName("webView")
        self.gridLayout_5.addWidget(self.webView, 0, 0, 1, 1)
        self.tabWidget.addTab(self.html_tab, "")
        self.source_tab = QtGui.QWidget()
        self.source_tab.setObjectName("source_tab")
        self.gridLayout_6 = QtGui.QGridLayout(self.source_tab)
        self.gridLayout_6.setMargin(0)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.htmlSource = QtGui.QPlainTextEdit(self.source_tab)
        self.htmlSource.setReadOnly(True)
        self.htmlSource.setObjectName("htmlSource")
        self.gridLayout_6.addWidget(self.htmlSource, 0, 0, 1, 1)
        self.tabWidget.addTab(self.source_tab, "")
        self.gridLayout_2.addWidget(self.tabWidget, 0, 0, 1, 2)
        self.slugEdit = QtGui.QLineEdit(self.centralwidget)
        self.slugEdit.setObjectName("slugEdit")
        self.gridLayout_2.addWidget(self.slugEdit, 1, 1, 1, 1)
        self.slugLabel = QtGui.QLabel(self.centralwidget)
        self.slugLabel.setMargin(3)
        self.slugLabel.setObjectName("slugLabel")
        self.gridLayout_2.addWidget(self.slugLabel, 1, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.dockWidget = QtGui.QDockWidget(MainWindow)
        self.dockWidget.setEnabled(True)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dockWidget.sizePolicy().hasHeightForWidth())
        self.dockWidget.setSizePolicy(sizePolicy)
        self.dockWidget.setMinimumSize(QtCore.QSize(92, 166))
        self.dockWidget.setStyleSheet("None")
        self.dockWidget.setFloating(False)
        self.dockWidget.setFeatures(QtGui.QDockWidget.NoDockWidgetFeatures)
        self.dockWidget.setObjectName("dockWidget")
        self.dockWidgetContents = QtGui.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.gridLayout = QtGui.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setSpacing(3)
        self.gridLayout.setContentsMargins(0, 3, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.padList = QtGui.QComboBox(self.dockWidgetContents)
        self.padList.setFrame(True)
        self.padList.setObjectName("padList")
        self.gridLayout.addWidget(self.padList, 0, 0, 1, 1)
        self.tree = QtGui.QTreeWidget(self.dockWidgetContents)
        self.tree.setAutoFillBackground(False)
        self.tree.setFrameShape(QtGui.QFrame.StyledPanel)
        self.tree.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.tree.setIndentation(20)
        self.tree.setRootIsDecorated(True)
        self.tree.setUniformRowHeights(False)
        self.tree.setItemsExpandable(True)
        self.tree.setAnimated(False)
        self.tree.setWordWrap(False)
        self.tree.setHeaderHidden(True)
        self.tree.setExpandsOnDoubleClick(True)
        self.tree.setObjectName("tree")
        self.tree.headerItem().setText(0, "1")
        self.tree.header().setDefaultSectionSize(0)
        self.tree.header().setMinimumSectionSize(0)
        self.tree.header().setStretchLastSection(True)
        self.gridLayout.addWidget(self.tree, 1, 0, 1, 1)
        self.dockWidget.setWidget(self.dockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.dockWidget)
        self.toolBar = QtGui.QToolBar(MainWindow)
        self.toolBar.setIconSize(QtCore.QSize(16, 16))
        self.toolBar.setObjectName("toolBar")
        MainWindow.addToolBar(QtCore.Qt.ToolBarArea(QtCore.Qt.TopToolBarArea), self.toolBar)
        self.actionSave = QtGui.QAction(MainWindow)
        self.actionSave.setCheckable(False)
        self.actionSave.setEnabled(False)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSave.setIcon(icon1)
        self.actionSave.setAutoRepeat(True)
        self.actionSave.setObjectName("actionSave")
        self.actionAddChild = QtGui.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/add_child.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAddChild.setIcon(icon2)
        self.actionAddChild.setAutoRepeat(True)
        self.actionAddChild.setObjectName("actionAddChild")
        self.actionDelete = QtGui.QAction(MainWindow)
        self.actionDelete.setEnabled(True)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/delete.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDelete.setIcon(icon3)
        self.actionDelete.setObjectName("actionDelete")
        self.actionMoveLeft = QtGui.QAction(MainWindow)
        self.actionMoveLeft.setEnabled(False)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/left.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionMoveLeft.setIcon(icon4)
        self.actionMoveLeft.setObjectName("actionMoveLeft")
        self.actionMoveRight = QtGui.QAction(MainWindow)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/right.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionMoveRight.setIcon(icon5)
        self.actionMoveRight.setObjectName("actionMoveRight")
        self.actionMoveUp = QtGui.QAction(MainWindow)
        self.actionMoveUp.setEnabled(True)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/up.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionMoveUp.setIcon(icon6)
        self.actionMoveUp.setObjectName("actionMoveUp")
        self.actionMoveDown = QtGui.QAction(MainWindow)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/down.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionMoveDown.setIcon(icon7)
        self.actionMoveDown.setObjectName("actionMoveDown")
        self.actionAddSibling = QtGui.QAction(MainWindow)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/add_sibling.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAddSibling.setIcon(icon8)
        self.actionAddSibling.setObjectName("actionAddSibling")
        self.actionNewPad = QtGui.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/new_pad.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionNewPad.setIcon(icon9)
        self.actionNewPad.setObjectName("actionNewPad")
        self.actionSettings = QtGui.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/settings.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSettings.setIcon(icon10)
        self.actionSettings.setObjectName("actionSettings")
        self.actionSync = QtGui.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/sync.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSync.setIcon(icon11)
        self.actionSync.setObjectName("actionSync")
        self.actionCopyUrl = QtGui.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/copy_link.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCopyUrl.setIcon(icon12)
        self.actionCopyUrl.setObjectName("actionCopyUrl")
        self.toolBar.addAction(self.actionNewPad)
        self.toolBar.addAction(self.actionSave)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionSettings)
        self.toolBar.addAction(self.actionSync)
        self.toolBar.addAction(self.actionCopyUrl)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionAddChild)
        self.toolBar.addAction(self.actionAddSibling)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionMoveUp)
        self.toolBar.addAction(self.actionMoveDown)
        self.toolBar.addAction(self.actionMoveLeft)
        self.toolBar.addAction(self.actionMoveRight)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.actionDelete)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "zenpad.ru", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.text_tab), QtGui.QApplication.translate("MainWindow", "Text Edit", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.html_tab), QtGui.QApplication.translate("MainWindow", "Html View", None, QtGui.QApplication.UnicodeUTF8))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.source_tab), QtGui.QApplication.translate("MainWindow", "Html Source", None, QtGui.QApplication.UnicodeUTF8))
        self.slugLabel.setText(QtGui.QApplication.translate("MainWindow", "Url-name", None, QtGui.QApplication.UnicodeUTF8))
        self.tree.setSortingEnabled(False)
        self.toolBar.setWindowTitle(QtGui.QApplication.translate("MainWindow", "toolBar", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave.setText(QtGui.QApplication.translate("MainWindow", "&Save", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave.setToolTip(QtGui.QApplication.translate("MainWindow", "сохранить", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+S", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAddChild.setText(QtGui.QApplication.translate("MainWindow", "&Add Child", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAddChild.setToolTip(QtGui.QApplication.translate("MainWindow", "добавить потомка", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAddChild.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+A", None, QtGui.QApplication.UnicodeUTF8))
        self.actionDelete.setText(QtGui.QApplication.translate("MainWindow", "&Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.actionDelete.setToolTip(QtGui.QApplication.translate("MainWindow", "удалить", None, QtGui.QApplication.UnicodeUTF8))
        self.actionDelete.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+D", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMoveLeft.setText(QtGui.QApplication.translate("MainWindow", "Move&Left", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMoveLeft.setToolTip(QtGui.QApplication.translate("MainWindow", "передвинуть влево", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMoveRight.setText(QtGui.QApplication.translate("MainWindow", "Move&Right", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMoveRight.setToolTip(QtGui.QApplication.translate("MainWindow", "передвинуть вправо", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMoveUp.setText(QtGui.QApplication.translate("MainWindow", "Move&Up", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMoveUp.setToolTip(QtGui.QApplication.translate("MainWindow", "передвинуть вверх", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMoveDown.setText(QtGui.QApplication.translate("MainWindow", "Move&Down", None, QtGui.QApplication.UnicodeUTF8))
        self.actionMoveDown.setToolTip(QtGui.QApplication.translate("MainWindow", "передвинуть вниз", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAddSibling.setText(QtGui.QApplication.translate("MainWindow", "AddS&ibling", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAddSibling.setToolTip(QtGui.QApplication.translate("MainWindow", "добавить соседа", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNewPad.setText(QtGui.QApplication.translate("MainWindow", "NewPad", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNewPad.setToolTip(QtGui.QApplication.translate("MainWindow", "создать новый блокнот", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSettings.setText(QtGui.QApplication.translate("MainWindow", "Settings", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSettings.setToolTip(QtGui.QApplication.translate("MainWindow", "Настройки", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSync.setText(QtGui.QApplication.translate("MainWindow", "Sync", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSync.setToolTip(QtGui.QApplication.translate("MainWindow", "Синхронизация с zenpad.ru", None, QtGui.QApplication.UnicodeUTF8))
        self.actionCopyUrl.setText(QtGui.QApplication.translate("MainWindow", "getUrl", None, QtGui.QApplication.UnicodeUTF8))
        self.actionCopyUrl.setToolTip(QtGui.QApplication.translate("MainWindow", "Скопировать урл страницы", None, QtGui.QApplication.UnicodeUTF8))

from PyQt4 import QtWebKit
import resources_rc
